# hangar-api
This page describes the format for the current Hangar REST API as well as general usage guidelines.<br>
Note that all routes **not** listed here should be considered **internal**, and can change at a moment's notice. **Do not use them**.

## Authentication and Authorization
There are two ways to consume the API: Authenticated or anonymous.

### Anonymous
When using anonymous authentication, you only have access to public information, but you don't need to worry about creating and storing an API key or handing JWTs.

### Authenticated
If you need access to non-public content or actions, you need to create and use API keys.
These can be created by going to the API keys page via the profile dropdown or by going to your user page and clicking on the key icon.

API keys allow you to impersonate yourself, so they should be handled like passwords. **Do not share them with anyone else!**

#### Getting and Using a JWT
Once you have an API key, you need to authenticate yourself: Send a `POST` request with your API key identifier to `/api/v1/authenticate?apiKey=yourKey`.
The response will contain your JWT as well as an expiration time.
Put this JWT into the `Authorization` header of every request and make sure to request a new JWT after the expiration time has passed.

Please also set a meaningful `User-Agent` header. This allows us to better identify loads and needs for potentially new endpoints.

## Misc
### Date Formats
Standard ISO types. Where possible, we use the [OpenAPI format modifier](https://swagger.io/docs/specification/data-models/data-types/#format).

### Rate Limits and Caching
The default rate limit is set at 20 requests every 5 seconds with an initial overdraft for extra leniency.
Individual endpoints, such as version creation, may have stricter rate limiting.

If applicable, always cache responses. The Hangar API itself is cached by CloudFlare and internally.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 2023.11
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import hangar_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import hangar_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import hangar_api
from hangar_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://hangar.papermc.io
# See configuration.py for a list of all supported configuration parameters.
configuration = hangar_api.Configuration(
    host = "https://hangar.papermc.io"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): HangarAuth
configuration = hangar_api.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with hangar_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = hangar_api.APIKeysApi(api_client)
    create_api_key_form = hangar_api.CreateAPIKeyForm() # CreateAPIKeyForm | 

    try:
        # Creates an API key
        api_response = api_instance.create_key(create_api_key_form)
        print("The response of APIKeysApi->create_key:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling APIKeysApi->create_key: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://hangar.papermc.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*APIKeysApi* | [**create_key**](docs/APIKeysApi.md#create_key) | **POST** /api/v1/keys | Creates an API key
*APIKeysApi* | [**delete_key**](docs/APIKeysApi.md#delete_key) | **DELETE** /api/v1/keys | Deletes an API key
*APIKeysApi* | [**get_keys**](docs/APIKeysApi.md#get_keys) | **GET** /api/v1/keys | Fetches a list of API Keys
*AuthenticationApi* | [**authenticate**](docs/AuthenticationApi.md#authenticate) | **POST** /api/v1/authenticate | Creates an API JWT
*PagesApi* | [**edit_main_page**](docs/PagesApi.md#edit_main_page) | **PATCH** /api/v1/pages/editmain/{slug} | Edits the main page of a project
*PagesApi* | [**edit_page**](docs/PagesApi.md#edit_page) | **PATCH** /api/v1/pages/edit/{slug} | Edits a page of a project
*PagesApi* | [**get_main_page**](docs/PagesApi.md#get_main_page) | **GET** /api/v1/pages/main/{slug} | Returns the main page of a project
*PagesApi* | [**get_page**](docs/PagesApi.md#get_page) | **GET** /api/v1/pages/page/{slug} | Returns a page of a project
*PermissionsApi* | [**has_all**](docs/PermissionsApi.md#has_all) | **GET** /api/v1/permissions/hasAll | Checks whether you have all the provided permissions
*PermissionsApi* | [**has_any**](docs/PermissionsApi.md#has_any) | **GET** /api/v1/permissions/hasAny | Checks whether you have at least one of the provided permissions
*PermissionsApi* | [**show_permissions**](docs/PermissionsApi.md#show_permissions) | **GET** /api/v1/permissions | Returns your permissions
*ProjectsApi* | [**get_project**](docs/ProjectsApi.md#get_project) | **GET** /api/v1/projects/{slug} | Returns info on a specific project
*ProjectsApi* | [**get_project_members**](docs/ProjectsApi.md#get_project_members) | **GET** /api/v1/projects/{slug}/members | Returns the members of a project
*ProjectsApi* | [**get_project_stargazers**](docs/ProjectsApi.md#get_project_stargazers) | **GET** /api/v1/projects/{slug}/stargazers | Returns the stargazers of a project
*ProjectsApi* | [**get_project_watchers**](docs/ProjectsApi.md#get_project_watchers) | **GET** /api/v1/projects/{slug}/watchers | Returns the watchers of a project
*ProjectsApi* | [**get_projects**](docs/ProjectsApi.md#get_projects) | **GET** /api/v1/projects | Searches the projects on Hangar
*ProjectsApi* | [**show_project_stats**](docs/ProjectsApi.md#show_project_stats) | **GET** /api/v1/projects/{slug}/stats | Returns the stats for a project
*UsersApi* | [**get_authors**](docs/UsersApi.md#get_authors) | **GET** /api/v1/authors | Returns all users with at least one public project
*UsersApi* | [**get_staff**](docs/UsersApi.md#get_staff) | **GET** /api/v1/staff | Returns Hangar staff
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /api/v1/users/{user} | Returns a specific user
*UsersApi* | [**get_user_pinned_projects**](docs/UsersApi.md#get_user_pinned_projects) | **GET** /api/v1/users/{user}/pinned | Returns the pinned projects for a specific user
*UsersApi* | [**get_user_watching**](docs/UsersApi.md#get_user_watching) | **GET** /api/v1/users/{user}/watching | Returns the watched projects for a specific user
*UsersApi* | [**show_starred**](docs/UsersApi.md#show_starred) | **GET** /api/v1/users/{user}/starred | Returns the starred projects for a specific user
*UsersApi* | [**show_users**](docs/UsersApi.md#show_users) | **GET** /api/v1/users | Searches for users
*VersionsApi* | [**download_version**](docs/VersionsApi.md#download_version) | **GET** /api/v1/projects/{slug}/versions/{name}/{platform}/download | Downloads a version
*VersionsApi* | [**download_version1**](docs/VersionsApi.md#download_version1) | **GET** /api/v1/projects/{author}/{slug}/versions/{name}/{platform}/download | 
*VersionsApi* | [**get_latest_release_version**](docs/VersionsApi.md#get_latest_release_version) | **GET** /api/v1/projects/{author}/{slug}/latestrelease | 
*VersionsApi* | [**get_latest_version**](docs/VersionsApi.md#get_latest_version) | **GET** /api/v1/projects/{author}/{slug}/latest | 
*VersionsApi* | [**get_version**](docs/VersionsApi.md#get_version) | **GET** /api/v1/projects/{author}/{slug}/versions/{name} | 
*VersionsApi* | [**get_version_stats**](docs/VersionsApi.md#get_version_stats) | **GET** /api/v1/projects/{author}/{slug}/versions/{name}/stats | 
*VersionsApi* | [**get_versions**](docs/VersionsApi.md#get_versions) | **GET** /api/v1/projects/{author}/{slug}/versions | 
*VersionsApi* | [**latest_release_version**](docs/VersionsApi.md#latest_release_version) | **GET** /api/v1/projects/{slug}/latestrelease | Returns the latest release version of a project
*VersionsApi* | [**latest_version**](docs/VersionsApi.md#latest_version) | **GET** /api/v1/projects/{slug}/latest | Returns the latest version of a project for a specific channel
*VersionsApi* | [**list_versions**](docs/VersionsApi.md#list_versions) | **GET** /api/v1/projects/{slug}/versions | Returns all versions of a project
*VersionsApi* | [**show_version**](docs/VersionsApi.md#show_version) | **GET** /api/v1/projects/{slug}/versions/{name} | Returns a specific version of a project
*VersionsApi* | [**show_version_stats**](docs/VersionsApi.md#show_version_stats) | **GET** /api/v1/projects/{slug}/versions/{name}/stats | Returns the stats for a version
*VersionsApi* | [**upload_version**](docs/VersionsApi.md#upload_version) | **POST** /api/v1/projects/{slug}/upload | Creates a new version and returns parts of its metadata
*VersionsApi* | [**upload_version1**](docs/VersionsApi.md#upload_version1) | **POST** /api/v1/projects/{author}/{slug}/upload | 


## Documentation For Models

 - [ApiKey](docs/ApiKey.md)
 - [ApiSession](docs/ApiSession.md)
 - [Category](docs/Category.md)
 - [ChannelFlag](docs/ChannelFlag.md)
 - [Color](docs/Color.md)
 - [CompactRole](docs/CompactRole.md)
 - [CreateAPIKeyForm](docs/CreateAPIKeyForm.md)
 - [DayProjectStats](docs/DayProjectStats.md)
 - [FileInfo](docs/FileInfo.md)
 - [Link](docs/Link.md)
 - [LinkSection](docs/LinkSection.md)
 - [MultipartFileOrUrl](docs/MultipartFileOrUrl.md)
 - [NamedPermission](docs/NamedPermission.md)
 - [PageEditForm](docs/PageEditForm.md)
 - [PaginatedResultProject](docs/PaginatedResultProject.md)
 - [PaginatedResultProjectCompact](docs/PaginatedResultProjectCompact.md)
 - [PaginatedResultProjectMember](docs/PaginatedResultProjectMember.md)
 - [PaginatedResultUser](docs/PaginatedResultUser.md)
 - [PaginatedResultVersion](docs/PaginatedResultVersion.md)
 - [Pagination](docs/Pagination.md)
 - [PermissionCheck](docs/PermissionCheck.md)
 - [PermissionType](docs/PermissionType.md)
 - [PinnedStatus](docs/PinnedStatus.md)
 - [Platform](docs/Platform.md)
 - [PlatformVersionDownload](docs/PlatformVersionDownload.md)
 - [PluginDependency](docs/PluginDependency.md)
 - [Project](docs/Project.md)
 - [ProjectChannel](docs/ProjectChannel.md)
 - [ProjectCompact](docs/ProjectCompact.md)
 - [ProjectDonationSettings](docs/ProjectDonationSettings.md)
 - [ProjectLicense](docs/ProjectLicense.md)
 - [ProjectMember](docs/ProjectMember.md)
 - [ProjectNamespace](docs/ProjectNamespace.md)
 - [ProjectSettings](docs/ProjectSettings.md)
 - [ProjectSortingStrategy](docs/ProjectSortingStrategy.md)
 - [ProjectStats](docs/ProjectStats.md)
 - [RequestPagination](docs/RequestPagination.md)
 - [ReviewState](docs/ReviewState.md)
 - [StringContent](docs/StringContent.md)
 - [UploadedVersion](docs/UploadedVersion.md)
 - [User](docs/User.md)
 - [UserActions](docs/UserActions.md)
 - [UserNameChange](docs/UserNameChange.md)
 - [UserPermissions](docs/UserPermissions.md)
 - [Version](docs/Version.md)
 - [VersionStats](docs/VersionStats.md)
 - [VersionUpload](docs/VersionUpload.md)
 - [Visibility](docs/Visibility.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="HangarAuth"></a>
### HangarAuth

- **Type**: Bearer authentication (JWT)


## Author




